==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
var WebPageCancellableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPageCancellableEventArgsDescriptionMetadata, _super);
    function WebPageCancellableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageCancellableEventArgsDescriptionMetadata.b = function (a) {
        if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
            WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPageCancellableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPageCancellableEventArgsDescriptionMetadata.a);
        WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
    };
    WebPageCancellableEventArgsDescriptionMetadata.d = function (a) {
        WebPageCancellableEventArgsDescriptionMetadata.b(a);
        a.ad("WebPageCancellableEventArgs", function () { return new WebPageCancellableEventArgsDescription(); });
        a.ac("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.$t = markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
}(Base));
export { WebPageCancellableEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
var WebPageCancellableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPageCancellableEventArgsDescriptionMetadata, _super);
    function WebPageCancellableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageCancellableEventArgsDescriptionMetadata.b = function (a) {
        if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
            WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPageCancellableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPageCancellableEventArgsDescriptionMetadata.a);
        WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
    };
    WebPageCancellableEventArgsDescriptionMetadata.d = function (a) {
        WebPageCancellableEventArgsDescriptionMetadata.b(a);
        a.ae("WebPageCancellableEventArgs", function () { return new WebPageCancellableEventArgsDescription(); });
        a.ad("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.$t = markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
}(Base));
export { WebPageCancellableEventArgsDescriptionMetadata };
